intelmq.bots.outputs.rt namespace — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.rt namespace

## Submodules

## intelmq.bots.outputs.rt.output module

Request Tracker output bot

Creates a ticket in the specified queue Parameters: rt_uri, rt_user, rt_password, verify_cert - RT API endpoint queue - ticket destination queue CF_mapping - mapping attributes-ticket CFs final_status - what is final status for the created ticket create_investigation - should we create Investigation ticket (in case of RTIR workflow) fieldnames - attributes to include into investigation ticket description_attr - which event attribute contains text message being sent to the recipient

`intelmq.bots.outputs.rt.output.` `BOT`

  alias of `intelmq.bots.outputs.rt.output.RTOutputBot`

class `intelmq.bots.outputs.rt.output.` `RTOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()